@@ -114,7 +114,7 @@ pub struct TestEnvironment {
   #[cfg(windows)]
   path_dirs: Arc<Mutex<Vec<PathBuf>>>,
   cpu_arch: Arc<Mutex<String>>,
-  core_count: Arc<Mutex<usize>>,
+  max_threads_count: Arc<Mutex<usize>>,
   current_exe_path: Arc<Mutex<PathBuf>>,
 }
 
@@ -147,7 +147,7 @@ impl TestEnvironment {
       #[cfg(windows)]
       path_dirs: Default::default(),
       cpu_arch: Arc::new(Mutex::new("x86_64".to_string())),
-      core_count: Arc::new(Mutex::new(std::thread::available_parallelism().map(|p| p.get()).unwrap_or(4))),
+      max_threads_count: Arc::new(Mutex::new(std::thread::available_parallelism().map(|p| p.get()).unwrap_or(4))),
       current_exe_path: Arc::new(Mutex::new(PathBuf::from("/dprint"))),
     }
   }
@@ -244,8 +244,8 @@ impl TestEnvironment {
     *self.cpu_arch.lock() = value.to_string();
   }
 
-  pub fn set_available_parallelism(&self, value: usize) {
-    *self.core_count.lock() = value;
+  pub fn set_max_threads(&self, value: usize) {
+    *self.max_threads_count.lock() = value;
   }
 
   pub fn set_runtime_handle(&self, handle: tokio::runtime::Handle) {
@@ -497,8 +497,8 @@ impl Environment for TestEnvironment {
     std::env::consts::OS.to_string()
   }
 
-  fn available_parallelism(&self) -> usize {
-    *self.core_count.lock()
+  fn max_threads(&self) -> usize {
+    *self.max_threads_count.lock()
   }
 
   fn cli_version(&self) -> String {
