@@ -172,8 +172,10 @@ OPTIONS:
         --verbose                    Prints additional diagnostic information.
 
 ENVIRONMENT VARIABLES:
-  DPRINT_CACHE_DIR    The directory to store the dprint cache. Note that
-                      this directory may be periodically deleted by the CLI.
+  DPRINT_CACHE_DIR    Directory to store the dprint cache. Note that this
+                      directory may be periodically deleted by the CLI.
+  DPRINT_MAX_THREADS  Limit the number of threads dprint uses for
+                      formatting (ex. DPRINT_MAX_THREADS=4).
   HTTPS_PROXY         Proxy to use when downloading plugins or configuration
                       files (set HTTP_PROXY for HTTP).
 
